package com.ruoyi.kyTask.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.kyTask.mapper.KyTaskInfoMapper;
import com.ruoyi.kyTask.domain.KyTaskInfo;
import com.ruoyi.kyTask.service.IKyTaskInfoService;

/**
 * 科研任务Service业务层处理
 * 
 * @author yanxun
 * @date 2023-08-10
 */
@Service
public class KyTaskInfoServiceImpl implements IKyTaskInfoService 
{
    @Autowired
    private KyTaskInfoMapper kyTaskInfoMapper;

    /**
     * 查询科研任务
     * 
     * @param key 科研任务主键
     * @return 科研任务
     */
    @Override
    public KyTaskInfo selectKyTaskInfoByKey(Long key)
    {
        return kyTaskInfoMapper.selectKyTaskInfoByKey(key);
    }

    /**
     * 查询科研任务列表
     * 
     * @param kyTaskInfo 科研任务
     * @return 科研任务
     */
    @Override
    public List<KyTaskInfo> selectKyTaskInfoList(KyTaskInfo kyTaskInfo)
    {
        return kyTaskInfoMapper.selectKyTaskInfoList(kyTaskInfo);
    }

    /**
     * 新增科研任务
     * 
     * @param kyTaskInfo 科研任务
     * @return 结果
     */
    @Override
    public int insertKyTaskInfo(KyTaskInfo kyTaskInfo)
    {
        return kyTaskInfoMapper.insertKyTaskInfo(kyTaskInfo);
    }

    /**
     * 修改科研任务
     * 
     * @param kyTaskInfo 科研任务
     * @return 结果
     */
    @Override
    public int updateKyTaskInfo(KyTaskInfo kyTaskInfo)
    {
        return kyTaskInfoMapper.updateKyTaskInfo(kyTaskInfo);
    }

    /**
     * 批量删除科研任务
     * 
     * @param keys 需要删除的科研任务主键
     * @return 结果
     */
    @Override
    public int deleteKyTaskInfoByKeys(Long[] keys)
    {
        return kyTaskInfoMapper.deleteKyTaskInfoByKeys(keys);
    }

    /**
     * 删除科研任务信息
     * 
     * @param key 科研任务主键
     * @return 结果
     */
    @Override
    public int deleteKyTaskInfoByKey(Long key)
    {
        return kyTaskInfoMapper.deleteKyTaskInfoByKey(key);
    }

    /**
     * 获取科研任务总数
     *
     * @return 结果
     */
    @Override
    public int getTaskCount() {
        return kyTaskInfoMapper.getTaskCount();
    }

    /**
     * 查找偏移量范围内的科研任务
     *
     * @param beginOffset 开始偏移量
     * @param endOffset 结束偏移量
     * @return 结果
     */
    @Override
    public List<KyTaskInfo> selectKyTaskInfoListByRange(int beginOffset, int size) {
        return kyTaskInfoMapper.seletcKyTaskInfoListByRanage(beginOffset,size);
    }
}
