package com.ruoyi.mesInfo.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mesInfo.mapper.MesInfoMapper;
import com.ruoyi.mesInfo.domain.MesInfo;
import com.ruoyi.mesInfo.service.IMesInfoService;

/**
 * mes装机信息卡Service业务层处理
 * 
 * @author yanxun
 * @date 2023-08-10
 */
@Service
public class MesInfoServiceImpl implements IMesInfoService 
{
    @Autowired
    private MesInfoMapper mesInfoMapper;

    /**
     * 查询mes装机信息卡
     * 
     * @param keyId mes装机信息卡主键
     * @return mes装机信息卡
     */
    @Override
    public MesInfo selectMesInfoByKeyId(Long keyId)
    {
        return mesInfoMapper.selectMesInfoByKeyId(keyId);
    }

    /**
     * 查询mes装机信息卡列表
     * 
     * @param mesInfo mes装机信息卡
     * @return mes装机信息卡
     */
    @Override
    public List<MesInfo> selectMesInfoList(MesInfo mesInfo)
    {
        return mesInfoMapper.selectMesInfoList(mesInfo);
    }

    /**
     * 新增mes装机信息卡
     * 
     * @param mesInfo mes装机信息卡
     * @return 结果
     */
    @Override
    public int insertMesInfo(MesInfo mesInfo)
    {
        return mesInfoMapper.insertMesInfo(mesInfo);
    }

    /**
     * 修改mes装机信息卡
     * 
     * @param mesInfo mes装机信息卡
     * @return 结果
     */
    @Override
    public int updateMesInfo(MesInfo mesInfo)
    {
        return mesInfoMapper.updateMesInfo(mesInfo);
    }

    /**
     * 批量删除mes装机信息卡
     * 
     * @param keyIds 需要删除的mes装机信息卡主键
     * @return 结果
     */
    @Override
    public int deleteMesInfoByKeyIds(Long[] keyIds)
    {
        return mesInfoMapper.deleteMesInfoByKeyIds(keyIds);
    }

    /**
     * 删除mes装机信息卡信息
     * 
     * @param keyId mes装机信息卡主键
     * @return 结果
     */
    @Override
    public int deleteMesInfoByKeyId(Long keyId)
    {
        return mesInfoMapper.deleteMesInfoByKeyId(keyId);
    }

    /**
     * 获取上次处理的装机信息卡最后一条数据的主键
     *
     * @return 结果
     */
    @Override
    public Long selectCheckPoint() {
        return mesInfoMapper.selectCheckPoint();
    }

    /**
     * 获取当前装机信息卡最大的主键
     * @return 结果
     */
    @Override
    public Long getMesInfoMaxKeyId() {
        return mesInfoMapper.getMesInfoMaxKeyId();
    }

    /**
     * 获取key_id主键大于startId并且小于endId的所有数据
     * @return 结果
     */
    @Override
    public List<MesInfo> selectMesInfoByKeyIdRange(Long startId, Long endId) {
        return mesInfoMapper.selectMesInfoByKeyIdRange(startId,endId);
    }

    /**
     * 记录最新的检查点Id
     * @param checkPointId 记录最新检查点Id
     * @return 结果
     */
    @Override
    public int recordCheckPoint(long checkPointId) {
        return mesInfoMapper.recordCheckPoint(checkPointId);
    }
}
